'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');
var templateParams = require('../templateParams.json');
var child_process = require('child_process');
var os = require('os');
var file = require('fs');

module.exports = yeoman.Base.extend({
  constructor: function(){ 
    yeoman.Base.apply(this, arguments);

    this.argument('apiname', { type: String, required: true });
  },
  prompting: function () {
    
    var prompts = [{
      type: 'confirm',
      name: 'answer',
      message: 'Would you like to export API?',
      default: true
    }];

    return this.prompt(prompts).then(function (props) {
      // To access props later use this.props.someAnswer;
      this.props = props;
    }.bind(this));
  },
  writing: function () {
    var params = templateParams.params;
    var mainParam = params.main;
    var protoParam = params.proto;

    var exportPath = 'src/OFK'+this.appname+'.c';
    var protoPath = 'include/OFKProto'+this.appname+'.h';

    var regex = /.*[\s](.*)\(/g;
    var funcName = regex.exec(this.apiname)[1];

    if (this.props.answer == false)
      return;
    
    mainParam.OFK_EXPORTAPI_DECLARE += "\n" + this.apiname + "\n{\n\n}\n";
    mainParam.OFK_IF_DECLARE += "\n\tOFK_IF_ENTRY("+funcName+")";
    
    this.apiname = this.apiname.replace('static ','');
    protoParam.OFK_PROTO_DECLARE += "\n\t"+this.apiname.replace('ofkif','OFKIF')+";";

    var tplData = [];
    
    tplData.push([exportPath, exportPath, mainParam]);
    tplData.push([protoPath, protoPath, protoParam]);

    tplData.forEach((e)=>{
      this.fs.copyTpl( e[0], e[1], e[2] );
    });

    var watcher = file.watch(protoPath, (event, filename) => {
        this.composeWith('thor-module:genProto', { options: { answer: true } });
        watcher.close();
    });

  }
});
